Class: Google::Cloud::Commerce::Consumer::Procurement::V1::LineItemChange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb

Overview

A change made on a line item.

Instance Attribute Summary collapse

Instance Attribute Details

#change_effective_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. A time at which the change became or will become (in case of pending change) effective.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#change_id::String (readonly)

Returns Output only. Change ID. All changes made within one order update operation have the same change_id.

Returns:

  • (::String)

    Output only. Change ID. All changes made within one order update operation have the same change_id.



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#change_state::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItemChangeState (readonly)

Returns Output only. State of the change.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#change_state_reason_type::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItemChangeStateReasonType (readonly)

Returns Output only. Predefined enum types for why this line item change is in current state. For example, a line item change's state could be LINE_ITEM_CHANGE_STATE_COMPLETED because of end-of-term expiration, immediate cancellation initiated by the user, or system-initiated cancellation.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#change_type::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItemChangeType

Returns Required. Type of the change to make.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when change was initiated.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_line_item_info::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItemInfo

Returns Line item info after the change.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#old_line_item_info::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItemInfo (readonly)

Returns Output only. Line item info before the change.

Returns:



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#state_reason::String (readonly)

Returns Output only. Provider-supplied message explaining the LineItemChange's state. Mainly used to communicate progress and ETA for provisioning in the case of PENDING_APPROVAL, and to explain why the change request was denied or canceled in the case of REJECTED and CANCELED states.

Returns:

  • (::String)

    Output only. Provider-supplied message explaining the LineItemChange's state. Mainly used to communicate progress and ETA for provisioning in the case of PENDING_APPROVAL, and to explain why the change request was denied or canceled in the case of REJECTED and CANCELED states.



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when change was updated, e.g. approved/rejected by partners or cancelled by the user.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The time when change was updated, e.g. approved/rejected by partners or cancelled by the user.



129
130
131
132
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 129

class LineItemChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end