Class: Google::Cloud::Commerce::Consumer::Procurement::V1::Order
- Inherits:
-
Object
- Object
- Google::Cloud::Commerce::Consumer::Procurement::V1::Order
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb
Overview
Represents a purchase made by a customer on Cloud Marketplace. Creating an order makes sure that both the Google backend systems as well as external service provider's systems (if needed) allow use of purchased products and ensures the appropriate billing events occur.
An Order can be made against one Product with multiple add-ons (optional) or one Quote which might reference multiple products.
Customers typically choose a price plan for each Product purchased when they create an order and can change their plan later, if the product allows.
Instance Attribute Summary collapse
-
#cancelled_line_items ⇒ ::Array<::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItem>
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#etag ⇒ ::String
The weak etag of the order.
-
#line_items ⇒ ::Array<::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItem>
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#cancelled_line_items ⇒ ::Array<::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItem> (readonly)
Returns Output only. Line items that were cancelled.
59 60 61 62 |
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 59 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The creation timestamp.
59 60 61 62 |
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 59 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The user-specified name of the order.
59 60 61 62 |
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 59 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#etag ⇒ ::String
Returns The weak etag of the order.
59 60 61 62 |
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 59 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#line_items ⇒ ::Array<::Google::Cloud::Commerce::Consumer::Procurement::V1::LineItem> (readonly)
Returns Output only. The items being purchased.
59 60 61 62 |
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 59 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. The resource name of the order.
Has the form
billingAccounts/{billing_account}/orders/{order}.
59 60 61 62 |
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 59 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last update timestamp.
59 60 61 62 |
# File 'proto_docs/google/cloud/commerce/consumer/procurement/v1/order.rb', line 59 class Order include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |